===============================
Tradecalc
===============================


.. image:: https://img.shields.io/pypi/v/tradecalc.svg
        :target: https://pypi.python.org/pypi/tradecalc

.. image:: https://img.shields.io/travis/toirl/tradecalc.svg
        :target: https://travis-ci.org/toirl/tradecalc

.. image:: https://readthedocs.org/projects/tradecalc/badge/?version=latest
        :target: https://tradecalc.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/toirl/tradecalc/shield.svg
     :target: https://pyup.io/repos/github/toirl/tradecalc/
     :alt: Updates


CLI tool to calculate trading positions for risk management on different
markets.


* Free software: MIT license
* Documentation: http://tradecalc.readthedocs.io/en/latest/
* Source: http://github.com/toirl/tradecalc


Features
--------

* Calculate max position size you can buy/sell at a given price, with a
  limited risk.

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

